==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/lens/KindleLens.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.lens;

import net.minecraft.class_1297;
import net.minecraft.class_1799;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_239;
import net.minecraft.class_2680;
import net.minecraft.class_3965;
import vazkii.botania.api.internal.ManaBurst;

public class KindleLens extends Lens {
	@Override
	public void updateBurst(ManaBurst burst, class_1799 stack) {
		class_1297 entity = burst.entity();
		if (!entity.field_6002.field_9236) {
			entity.method_5639(3);
		}
	}

	@Override
	public boolean collideBurst(ManaBurst burst, class_239 rtr, boolean isManaBlock, boolean shouldKill, class_1799 stack) {
		class_1297 entity = burst.entity();

		if (!entity.field_6002.field_9236 && rtr.method_17783() == class_239.class_240.field_1332
				&& !burst.isFake() && !isManaBlock) {
			class_3965 brtr = (class_3965) rtr;
			class_2338 pos = brtr.method_17777();
			class_2350 dir = brtr.method_17780();

			class_2338 offPos = pos.method_10093(dir);

			class_2680 stateAt = entity.field_6002.method_8320(pos);
			class_2680 stateAtOffset = entity.field_6002.method_8320(offPos);

			if (stateAt.method_27852(class_2246.field_10316)) {
				entity.field_6002.method_8650(pos, false);
			}
			if (stateAtOffset.method_27852(class_2246.field_10316)) {
				entity.field_6002.method_8650(offPos, false);
			} else if (stateAtOffset.method_26215()) {
				entity.field_6002.method_8501(offPos, class_2246.field_10036.method_9564());
			}
		}

		return shouldKill;
	}

}

==> Botania-1.20.1-451-FABRIC-20260116.182542-39-sources.jar: vazkii/botania/common/item/lens/KindleLens.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.lens;

import net.minecraft.class_1297;
import net.minecraft.class_1799;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_239;
import net.minecraft.class_2680;
import net.minecraft.class_3965;
import net.minecraft.class_4770;
import vazkii.botania.api.internal.ManaBurst;

public class KindleLens extends Lens {
	@Override
	public void updateBurst(ManaBurst burst, class_1799 stack) {
		class_1297 entity = burst.entity();
		if (!entity.method_37908().field_9236) {
			entity.method_5639(3);
		}
	}

	@Override
	public boolean collideBurst(ManaBurst burst, class_239 rtr, boolean isManaBlock, boolean shouldKill, class_1799 stack) {
		class_1297 entity = burst.entity();

		if (!entity.method_37908().field_9236 && rtr.method_17783() == class_239.class_240.field_1332
				&& !burst.isFake() && !isManaBlock) {
			class_3965 brtr = (class_3965) rtr;
			class_2338 pos = brtr.method_17777();
			class_2350 dir = brtr.method_17780();

			class_2338 offPos = pos.method_10093(dir);

			class_2680 stateAt = entity.method_37908().method_8320(pos);
			class_2680 stateAtOffset = entity.method_37908().method_8320(offPos);

			if (stateAt.method_27852(class_2246.field_10316)) {
				entity.method_37908().method_8650(pos, false);
			}
			if (stateAtOffset.method_27852(class_2246.field_10316)) {
				entity.method_37908().method_8650(offPos, false);
			} else if (class_4770.method_30032(entity.method_37908(), offPos, dir.method_10153())) {
				entity.method_37908().method_8501(offPos, class_4770.method_24416(entity.method_37908(), offPos));
			}
		}

		return shouldKill;
	}

}
